#[non_exhaustive]pub enum ProxyWarnLogContext {
UpstreamRetry,
DownstreamCache,
}Expand description
Context for proxy warning logs that can be suppressed by
ProxyHttp::suppress_proxy_warn_log.
These contexts are distinct from final proxy errors, which are handled by
ProxyHttp::suppress_error_log.
Experimental: this API may change or be removed until indicated otherwise.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UpstreamRetry
A proxy upstream attempt failed with a retryable error.
DownstreamCache
A downstream error was ignored so cache fill could continue.