Subrequest piping.
Along with subrequests themselves, subrequest piping as a feature is in alpha stages, APIs are highly unstable and subject to change at any point.
Unlike proxy_*, it is not a “true” proxy mode; the functions here help establish a pipe between the main downstream session and the subrequest (which in most cases will be used as a downstream session itself).
Furthermore, only downstream modules are invoked on the main downstream session, and the ProxyHttp trait filters are not run on the HttpTasks from the main session (the only relevant one being the request body filter).
Structs
- Pipe
Subrequest Error - Pipe
Subrequest State - Context struct as a result of subrequest piping.
- Saved
Body